@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.3.2'
+VERSION = '0.3.3'
 
 import os
 import sys
@@ -17,13 +17,10 @@ import string
 import curses
 
 width = 20
-def set_screen_width():
-    return
+def set_screen_width(screen):
     global width
     try:
-        screen = curses.initscr()
         (_, width) = screen.getmaxyx()
-        curses.endwin()
     except:
         width = 20
 
@@ -374,7 +371,7 @@ def easy_roll():
     kernel = Kernel(verbose=args.verbose)
 
     if args.verbose:
-        set_screen_width()
+        curses.wrapper(set_screen_width)
 
     kernel.version = args.new_version
     kernel.config_version = args.config_version
